/*
**
**  Editline system header file for Unix.
*/

#define strdup xc_strdup
extern char *xc_strdup(const char *s);
#define CRLF		"\r\n"

#include <sys/types.h>
#include <sys/stat.h>
/* extern int ioctl(int fildes, int request, ...);*/
#include <sys/ioctl.h>

#if	defined(USE_DIRENT)
#include <dirent.h>
typedef struct dirent	DIRENTRY;
#else
#include <sys/dir.h>
typedef struct direct	DIRENTRY;
#endif	/* defined(USE_DIRENT) */

#if	!defined(S_ISDIR)
#define S_ISDIR(m)		(((m) & S_IFMT) == S_IFDIR)
#endif	/* !defined(S_ISDIR) */

#ifdef BSD   /* 386BSD has bad toupper() tolower()  functions */
#ifdef i386
#undef tolower(c)
#undef toupper(c)
#define tolower(x) (((x)>0x40)&&((x)<0x5b)?((x)|0x20):(x))
#define toupper(x) (((x)>0x60)&&((x)<0x7b)?((x)&0xdf):(x))
#endif
#endif
